render

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Renderer

type Renderer struct {
	// contains filtered or unexported fields
}

func NewRenderer

func NewRenderer(format types.OutFormat, title string, noStyles bool) *Renderer

func (*Renderer) Render

func (r *Renderer) Render(scopes []*types.EnvScope, out io.Writer) error

Render is used for generating an output based on a built-in format.

func (*Renderer) RenderCustom

func (r *Renderer) RenderCustom(scopes []*types.EnvScope, tmplFilePath string, out io.Writer) error

RenderCustom is used for generating an output based on the given custom template file.

Jump to